@@ -27,8 +27,6 @@ test_that("appending rules", {
 })
 
 test_that("Printing works as expected", {
-  with_mock(
-    cat = function(x, sep) x,
-    rule <- print(make_rule("a", "b", "true")))
-  expect_equal(rule, c("a: b\n", "\ttrue\n"))
+  rule <- capture.output(make_rule("a", "b", "true"))
+  expect_equal(rule, c("a: b", "\ttrue"))
 })
